@@ -25,6 +25,7 @@ from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
 from framework.db.redis_db import RedisDB
 from framework.utils.log_util import logger
+from framework.utils.lark_util import LarkUtil
 from framework.utils.yaml_util import CachedYamlLoader
 from framework.exceptions import MysqlDBError, RedisDBError
 from framework.global_attribute import CONTEXT, CONFIG, _FRAMEWORK_CONTEXT
@@ -522,11 +523,13 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     terminalreporter.write(f"用例通过率: {pass_rate}%\n", green=True, bold=True)
     terminalreporter.write("====================================\n", blue=True, bold=True)
     CONTEXT.set("summary", {
+        "total": total,
         "passed": passed,
         "failed": failed,
         "skipped": skipped,
-        "total": total,
+        "pass_rate": pass_rate
     })
+    # LarkUtil(settings.LARK_WEBHOOK).send_test_report(total=total, passed=passed, failed=failed, skipped=skipped)
 
 
 def pytest_exception_interact(node, call, report):
@@ -577,6 +580,7 @@ def inner_login(app):
         expire_time = datetime.now() + timedelta(seconds=token_expiry)
         _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
 
+
 def login():
     def safe_call(func, name):
         try:
